==> nextcloud-app-mail-0.17.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/sl.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Pošta ·",
    "Inbox" : "Prejeto",
    "Sent" : "Poslano",
    "Drafts" : "Osnutki",
    "Archive" : "Arhiv",
    "Trash" : "Smeti",
    "Junk" : "Neželena pošta",
    "All" : "Vse",
    "Favorites" : "Priljubljene",
    "Auto detect failed. Please use manual mode." : "Samodejno zaznavanje je spodletelo. Zaznavo bo treba izvesti ročno.",
    "Updating account failed: " : "Posodobitev računa je spodletela:",
    "Creating account failed: " : "Ustvarjanje računa je spodletelo:",
    "Delete permanently" : "Trajno izbriši",
    "Auto" : "Samodejno",
    "Name" : "Ime",
    "Mail Address" : "Elektronski naslov",
    "Password" : "Geslo",
    "Manual" : "Ročno",
    "IMAP Settings" : "Nastavitve IMAP",
    "IMAP Host" : "Gostitelj IMAP",
    "IMAP Security" : "Varnost IMAP",
    "None" : "Brez",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Vrata IMAP",
    "IMAP User" : "Uporabnik IMAP",
    "IMAP Password" : "Geslo IMAP",
    "SMTP Settings" : "Nastavitve SMTP",
    "SMTP Host" : "Gostitelj SMTP",
    "SMTP Security" : "Varnost SMTP",
    "SMTP Port" : "Vrata SMTP",
    "SMTP User" : "Uporabnik SMTP",
    "SMTP Password" : "Geslo SMTP",
    "Save" : "Shrani",
    "Connect" : "Poveži",
    "Add mail account" : "Dodaj račun elektronske pošte",
    "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
    "Keyboard shortcuts" : "Tipkovne bližnjice",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ali iščete rešitev za šifriranje sporočil elektronske pošte? Namestite razširitev za brskalnik Mailvelope!",
    "from" : "od",
    "to" : "za",
    "+ cc/bcc" : "+kp/skp",
    "cc" : "kp",
    "bcc" : "skp",
    "Subject" : "Zadeva",
    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Upoštevajte, da je elektronska pošta prispela z naslova 'no-reply' zato odgovora najbrž ne bo nihče prebral.",
    "Message …" : "Sporočilo ...",
    "Saving draft …" : "Shranjujem osnutek ...",
    "Draft saved" : "Osnutek shranjen",
    "Uploading attachments …" : "Nalagam priloge ...",
    "Sending …" : "Pošiljanje ...",
    "Error sending your message" : "Napaka pri pošiljanju vašega sporočila",
    "Go back" : "Nazaj",
    "Retry" : "Poskusi  znova",
    "Message sent!" : "Sporočilo je poslano!",
    "Reply sent!" : "Odgovor je poslan!",
    "Write another message" : "Napišite novo sporočilo",
    "Send" : "Pošlji",
    "Uploading {percent}% …" : "Poteka nalaganje {percent}% …",
    "Upload attachment" : "Pošlji prilogo",
    "Add attachment from Files" : "Dodaj priloge iz Datotek",
    "Choose a file to add as attachment" : "Izbor datoteke za prilogo",
    "No messages in this folder" : "V tej mapi ni sporočil",
    "Draft: " : "Osnutek:",
    "Mark read" : "Označi kot prebrano",
    "Mark unread" : "Označi kot neprebrano",
    "Delete" : "Izbriši",
    "Report this bug" : "Prijavi hrošča",
    "Loading messages" : "Nalagam sporočila",
    "Not found" : "Ni mogoče najti",
    "Could not load your message" : "Ne morem naložiti sporočila",
    "Import into calendar" : "Uvozi v koledar",
    "Download attachment" : "Pošlji prilogo",
    "Save to Files" : "Shrani v Datoteke",
    "Choose a folder to store the attachment in" : "Izbor mape za shranjevanje prilog.",
    "Save all to Files" : "Shrani vse v Datoteke",
    "Choose a folder to store the attachments in" : "Izberi mapo za shranjevanje vseh prilog",
    "The images have been blocked to protect your privacy." : "Prikaz slik je bil onemogočen za zaščito vaše zasebnosti.",
    "Show images from this\tsender" : "Prikaži slike od \tsender",
    "New message" : "Novo sporočilo",
    "Settings" : "Nastavitve",
    "Edit" : "Spremeni",
    "Add folder" : "Dodaj mapo",
    "Show all folders" : "Pokaži vse mape",
    "Collapse folders" : "Zloži mape",
    "Loading …" : "Nalagam ...",
    "{total} messages ({unread} unread)" : "{total} sporočil ({unread} neprebranih)",
    "Mark all as read" : "Označi vse kot prebrano",
    "Mark all messages of this folder as read" : "Označi vsa sporočila v tej mapo kot prebrana",
    "Add subfolder" : "Dodaj podmapo",
    "Could not load your draft" : "Ne morem naložiti osnutka",
    "No message selected" : "Nobeno sporočilo ni izbrano",
    "Signature" : "Podpis",
    "A signature will be added to the text of new and response messages." : "Podpis bo dodan na vsa nova sporočila in odgovore",
    "Account Settings" : "Nastavitve računa",
    "Mail server" : "Poštni strežnik",
    "Speed up your Mail experience with these quick shortcuts." : "Pospešite svojo izkušnjo s Pošto s temi hitrimi bližnjicami.",
    "Compose new message" : "Novo sporočilo",
    "Newer message" : "Novejše sporočilo",
    "Older message" : "Starejše sporočilo",
    "Toggle star" : "Preklopi zvezdico",
    "Toggle unread" : "Preklopi neprebrano",
    "Search" : "Iskanje",
    "Refresh" : "Osveži",
    "Connect your mail account" : "Povežite svoj elektronski račun",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "Nextcloud Mail",
    "All inboxes" : "Vsi predali",
    "Could not load {tag}{name}{endtag}" : "Ne morem naložiti {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Napaka pri nalaganju {tag}{name}{endtag}",
    "Could not load the desired message" : "Ne morem naložiti želenega sporočila",
    "Could not load the message" : "Ne morem naložiti sporočila",
    "Error loading message" : "Napaka nalaganja sporočila",
    "Forwarding to %s" : "Posredujem na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Pritisnite tukaj če ne boste samodejno preusmerjeni v roku nekaj sekund.",
    "Redirect" : "Preusmeri",
    "The link leads to %s" : "Povezava vodi na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Če ne želite obiskati te strani, se lahko vrnete na <a href=\"%s\">pošto</a>.",
    "Continue to %s" : "Nadaljuj na %s"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-app-mail-0.18.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/sl.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Pošta ·",
    "Auto detect failed. Please use manual mode." : "Samodejno zaznavanje je spodletelo. Zaznavo bo treba izvesti ročno.",
    "Updating account failed: " : "Posodobitev računa je spodletela:",
    "Creating account failed: " : "Ustvarjanje računa je spodletelo:",
    "💌 A mail app for Nextcloud" : "💌 Poštni program za Nextcloud",
    "Auto" : "Samodejno",
    "Name" : "Ime",
    "Mail Address" : "Elektronski naslov",
    "Password" : "Geslo",
    "Manual" : "Ročno",
    "IMAP Settings" : "Nastavitve IMAP",
    "IMAP Host" : "Gostitelj IMAP",
    "IMAP Security" : "Varnost IMAP",
    "None" : "Brez",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Vrata IMAP",
    "IMAP User" : "Uporabnik IMAP",
    "IMAP Password" : "Geslo IMAP",
    "SMTP Settings" : "Nastavitve SMTP",
    "SMTP Host" : "Gostitelj SMTP",
    "SMTP Security" : "Varnost SMTP",
    "SMTP Port" : "Vrata SMTP",
    "SMTP User" : "Uporabnik SMTP",
    "SMTP Password" : "Geslo SMTP",
    "Save" : "Shrani",
    "Connect" : "Poveži",
    "Add mail account" : "Dodaj račun elektronske pošte",
    "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
    "Keyboard shortcuts" : "Tipkovne bližnjice",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ali iščete rešitev za šifriranje sporočil elektronske pošte? Namestite razširitev za brskalnik Mailvelope!",
    "Subject" : "Zadeva",
    "Saving draft …" : "Poteka shranjevanje osnutka ...",
    "Draft saved" : "Osnutek je shranjen",
    "Uploading attachments …" : "Poteka pošiljanje prilog ...",
    "Sending …" : "Poteka pošiljanje ...",
    "Error sending your message" : "Prošlo je do napake med pošiljanjem sporočila",
    "Go back" : "Nazaj",
    "Retry" : "Poskusi  znova",
    "Message sent!" : "Sporočilo je poslano!",
    "Reply sent!" : "Odgovor je poslan!",
    "Write another message" : "Sestavite novo sporočilo",
    "Send" : "Pošlji",
    "Uploading {percent}% …" : "Poteka nalaganje {percent}% …",
    "Upload attachment" : "Pošlji prilogo",
    "Add attachment from Files" : "Dodaj prilogo iz Datotek",
    "Choose a file to add as attachment" : "Izbor datoteke za prilogo",
    "No messages in this folder" : "V tej mapi ni sporočil",
    "Draft: " : "Osnutek:",
    "Mark read" : "Označi kot prebrano",
    "Mark unread" : "Označi kot neprebrano",
    "Delete" : "Izbriši",
    "Report this bug" : "Pošlji poročilo o hrošču",
    "Loading messages" : "Nalaganje sporočil",
    "Not found" : "Ni mogoče najti",
    "Reply" : "Odgovori",
    "Reply to sender only" : "Odgovori le pošiljatelju",
    "Forward" : "Posreduj",
    "Could not load your message" : "Sporočila ni mogoče naložiti",
    "Import into calendar" : "Uvozi v koledar",
    "Download attachment" : "Prejmi prilogo",
    "Save to Files" : "Shrani v Datoteke",
    "Choose a folder to store the attachment in" : "Izbor mape za shranjevanje priloge",
    "Save all to Files" : "Shrani vse v Datoteke",
    "Choose a folder to store the attachments in" : "Izbor mape za shranjevanje priloge",
    "The images have been blocked to protect your privacy." : "Za zaščito zasebnosti je prikaz slik onemogočen.",
    "Show images from this\tsender" : "Pokaži slike od tega \tpošiljatelja",
    "New message" : "Novo sporočilo",
    "Settings" : "Nastavitve",
    "Add folder" : "Dodaj mapo",
    "Show all folders" : "Pokaži vse mape",
    "Collapse folders" : "Zloži mape",
    "Mark all as read" : "Označi vse kot prebrano",
    "Add subfolder" : "Dodaj podmapo",
    "Could not load your draft" : "Osnutka ni mogoče naložiti",
    "No message selected" : "Ni izbranega nobenega sporočila",
    "Signature" : "Podpis",
    "Mail server" : "Poštni strežnik",
    "Speed up your Mail experience with these quick shortcuts." : "Pospešite svojo izkušnjo s Pošto s temi hitrimi bližnjicami.",
    "Compose new message" : "Novo sporočilo",
    "Newer message" : "Novejše sporočilo",
    "Older message" : "Starejše sporočilo",
    "Toggle star" : "Preklopi zvezdico",
    "Toggle unread" : "Preklopi neprebrano",
    "Search" : "Iskanje",
    "Refresh" : "Osveži",
    "Connect your mail account" : "Povežite svoj elektronski račun",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n novo sporočilo \npošilja {from}","%n novi sporočili \npošilja {from}","%n nova sporočila \npošilja {from}","%n novih sporočil \npošilja {from}"],
    "Nextcloud Mail" : "Pošta Nextcloud Mail",
    "All inboxes" : "Vsi predali",
    "Could not load {tag}{name}{endtag}" : "Ni mogoče naložiti {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Napaka pri nalaganju {tag}{name}{endtag}",
    "Could not load the desired message" : "Ne morem naložiti želenega sporočila",
    "Could not load the message" : "Ne morem naložiti sporočila",
    "Error loading message" : "Napaka nalaganja sporočila",
    "Forwarding to %s" : "Posredujem na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Pritisnite tukaj če ne boste samodejno preusmerjeni v roku nekaj sekund.",
    "Redirect" : "Preusmeri",
    "The link leads to %s" : "Povezava vodi na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Če ne želite obiskati te strani, se lahko vrnete na <a href=\"%s\">pošto</a>.",
    "Continue to %s" : "Nadaljuj na %s"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
